@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: error-viewer.c,v 1.15 2004/10/05 11:28:39 chpe Exp $
+ *  $Id: error-viewer.c,v 1.16 2005/01/13 16:15:47 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "error-viewer.h"
 #include "ephy-debug.h"
