@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-sidebar-embed.c,v 1.8 2005/03/07 19:11:08 jordim Exp $
+ * $Id: ephy-sidebar-embed.c,v 1.11 2005/04/19 11:30:19 chpe Exp $
  */
 
 #include "config.h"
@@ -154,11 +154,14 @@ hide_embed_popup_cb (GtkMenu *menu,
 	GtkAction *action;
 
 	action = gtk_ui_manager_get_action (manager, "/EphyInputPopup/EditCopyIP");
-	g_object_set (action, "sensitive", TRUE, "visible", TRUE, NULL);
+	gtk_action_set_sensitive (action, TRUE);
+	gtk_action_set_visible (action, TRUE);
 	action = gtk_ui_manager_get_action (manager, "/EphyInputPopup/EditCutIP");
-	g_object_set (action, "sensitive", TRUE, "visible", TRUE, NULL);
+	gtk_action_set_sensitive (action, TRUE);
+	gtk_action_set_visible (action, TRUE);
 	action = gtk_ui_manager_get_action (manager, "/EphyInputPopup/EditPasteIP");
-	g_object_set (action, "sensitive", TRUE, "visible", TRUE, NULL);
+	gtk_action_set_sensitive (action, TRUE);
+	gtk_action_set_visible (action, TRUE);
 }
 
 static void
@@ -223,22 +226,25 @@ show_context_menu (EphySidebarEmbed *sbembed,
 
 	manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
 	action = gtk_ui_manager_get_action (manager, "/EphySidebarDocumentPopup/SaveBackgroundAsDP");
-	g_object_set (action, "sensitive", has_background,
-			      "visible", has_background, NULL);
+	gtk_action_set_sensitive (action, has_background);
+	gtk_action_set_visible (action, has_background);
 	action = gtk_ui_manager_get_action (manager, "/EphyLinkPopup/OpenLinkInNewWindowLP");
-	g_object_set (action, "sensitive", can_open_in_new, FALSE);
+	gtk_action_set_sensitive (action, can_open_in_new);
 	action = gtk_ui_manager_get_action (manager, "/EphyLinkPopup/OpenLinkInNewTabLP");
-	g_object_set (action, "sensitive", can_open_in_new, FALSE);
+	gtk_action_set_sensitive (action, can_open_in_new);
 
 	can_copy = ephy_command_manager_can_do_command (EPHY_COMMAND_MANAGER (embed), "cmd_copy");
 	can_cut = ephy_command_manager_can_do_command (EPHY_COMMAND_MANAGER (embed), "cmd_cut");
 	can_paste = ephy_command_manager_can_do_command (EPHY_COMMAND_MANAGER (embed), "cmd_paste");
 	action = gtk_ui_manager_get_action (manager, "/EphyInputPopup/EditCopyIP");
-	g_object_set (action, "sensitive", can_copy, "visible", !hide_edit_actions || can_copy, NULL);
+	gtk_action_set_sensitive (action, can_copy);
+	gtk_action_set_visible (action, !hide_edit_actions || can_copy);
 	action = gtk_ui_manager_get_action (manager, "/EphyInputPopup/EditCutIP");
-	g_object_set (action, "sensitive", can_cut, "visible", !hide_edit_actions || can_cut, NULL);
+	gtk_action_set_sensitive (action, can_cut);
+	gtk_action_set_visible (action, !hide_edit_actions || can_cut);
 	action = gtk_ui_manager_get_action (manager, "/EphyInputPopup/EditPasteIP");
-	g_object_set (action, "sensitive", can_paste, "visible", !hide_edit_actions || can_paste, NULL);
+	gtk_action_set_sensitive (action, can_paste);
+	gtk_action_set_visible (action, !hide_edit_actions || can_paste);
 
 	g_object_set_data_full (G_OBJECT (window), "context_event",
 				g_object_ref (event),
@@ -386,25 +392,6 @@ embed_mouse_click_cb (EphyEmbed *embed,
 	return handled;
 }
 
-static void 
-embed_new_window_cb (EphyEmbed *embed,
-		     EphyEmbed **new_embed,
-		     EphyEmbedChrome chromemask,
-		     gpointer data)
-{
-	EphyWindow *window;
-	EphyTab *new_tab;
-
-	window = ephy_window_new_with_chrome (chromemask);
-
-	new_tab = ephy_tab_new ();
-	gtk_widget_show (GTK_WIDGET (new_tab));
-
-	ephy_window_add_tab (window, new_tab, -1, FALSE);
-
-	*new_embed = ephy_tab_get_embed (new_tab);
-}
-
 static void
 ephy_sidebar_embed_create_embed (EphySidebarEmbed *sbembed)
 {
@@ -423,10 +410,6 @@ ephy_sidebar_embed_create_embed (EphySidebarEmbed *sbembed)
 	{
 		ephy_embed_load_url (embed, sbembed->priv->url);
 
-		g_signal_connect (G_OBJECT (embed),
-				  "ge_new_window",
-				  G_CALLBACK(embed_new_window_cb),
-				  NULL);
 		g_signal_connect (G_OBJECT (embed),
 				  "ge_dom_mouse_click",
 				  G_CALLBACK(embed_mouse_click_cb),
@@ -440,7 +423,7 @@ ephy_sidebar_embed_create_embed (EphySidebarEmbed *sbembed)
 
 #define EPHY_STOCK_DOWNLOAD	"ephy-download"
 
-static GtkActionEntry action_entries [] =
+static const GtkActionEntry action_entries [] =
 {
 	{ "SidebarSaveAs", GTK_STOCK_SAVE_AS, N_("Save _As..."), NULL,
 	  N_("Save the current page"),
